@@ -1,6 +1,6 @@
 #######################################################################
 # Code to check parameter/control objects
-# Copyrigth (C) 2011 Michael Hahsler
+# Copyright (C) 2011 Michael Hahsler
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +20,9 @@
 ## helper to parse parameter lists with defaults
 .nodots <- function(...) {
   l <- list(...)
-  if(length(l) > 0L) warning("Unknown arguments: ",
-    paste(names(l), "=",l, collapse=", "))
+  if (length(l) > 0L)
+    warning("Unknown arguments: ",
+      paste(names(l), "=", l, collapse = ", "))
 }
 
 getParameters <- function(defaults, parameter) {
@@ -29,35 +30,41 @@ getParameters <- function(defaults, parameter) {
   parameter <- as.list(parameter)
 
   ## add verbose
-  if(is.null(defaults$verbose)) defaults$verbose <- FALSE
+  if (is.null(defaults$verbose))
+    defaults$verbose <- FALSE
 
-  if(length(parameter) != 0) {
+  if (length(parameter) != 0) {
     o <- pmatch(names(parameter), names(defaults))
 
     ## unknown parameter
-    if(any(is.na(o))){
-      warning(sprintf(ngettext(length(is.na(o)),
-        "Unknown parameter: %s",
-        "Unknown parameters: %s"),
+    if (any(is.na(o))) {
+      warning(sprintf(
+        ngettext(
+          length(is.na(o)),
+          "Unknown parameter: %s",
+          "Unknown parameters: %s"
+        ),
         paste(names(parameter)[is.na(o)],
-          collapse = ", ")), call. = FALSE, immediate. = TRUE)
+          collapse = ", ")
+      ),
+        call. = FALSE,
+        immediate. = TRUE)
 
       cat("Available parameter (with default values):\n")
       #print(defaults)
-      cat(rbind(names(defaults)," = ", gsub("\n"," ",as.character(defaults))),
-        sep=c("\t"," ","\n"))
+      cat(rbind(names(defaults), " = ", gsub("\n", " ", as.character(defaults))),
+        sep = c("\t", " ", "\n"))
     }
 
     defaults[o[!is.na(o)]] <- parameter[!is.na(o)]
   }
 
-  if(defaults$verbose) {
+  if (defaults$verbose) {
     cat("Used parameters:\n")
     #print(defaults)
-    cat(rbind(names(defaults)," = ", gsub("\n"," ",as.character(defaults))),
-      sep=c("\t"," ","\n"))
+    cat(rbind(names(defaults), " = ", gsub("\n", " ", as.character(defaults))),
+      sep = c("\t", " ", "\n"))
   }
 
   defaults
 }
-
